cmoncrawl.processor.pipeline.router
===================================

.. automodule:: cmoncrawl.processor.pipeline.router

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
   
      IRouter
      Route
      Router
   
   

   
   
   



